@@ -238,7 +238,7 @@ def coord_extractor_func(user_args):
     supported_exts = [".fchk", ".log", ".com"]
 
     if ext not in supported_exts:
-        os.exit("Error: Unsupported file extension!")
+        sys.exit("Error: Unsupported file extension!")
 
     parsers = [
         opt_extractor.read_coords_fchk,
@@ -322,12 +322,12 @@ def distort_func(user_args):
     # Read optimised structure from Gaussian
     labels, coords = opt_extractor.read_coords_log(user_args.log_file_name)
 
-    # Check user hasn't requested a stupid number
+    # Check user hasn't requested a wrong number
     n_modes = np.shape(props["displacements"])[1]
     if not 0 < user_args.mode <= n_modes:
         print('Invalid mode number selected')
         print('This molecule has {:d} modes'.format(n_modes))
-        exit()
+        sys.exit()
 
     # Distort along chosen vibrational mode by 1 unit of
     # normalised displacement vector
@@ -431,27 +431,50 @@ def cd_extractor_func(user_args):
     # Check log file has been provided
     check_file(user_args.log_file_name, ".log")
 
-    # Extract charges and dipoles
-    charges, dipoles = cd_extractor.get_charges_dipoles_log(
-        user_args.log_file_name
-    )
+    if user_args.mode == 'charges_dipoles':
 
-    out_head = user_args.log_file_name.split(".")[0]
+        # Extract charges and dipoles
+        charges, dipoles = cd_extractor.get_chelpg_charges_dipoles(
+            user_args.log_file_name
+        )
 
-    out_name = "{}_charges_dipoles.dat".format(out_head)
+        out_head = user_args.log_file_name.split(".")[0]
 
-    # output array of charges, dip_x, dip_y, dip_z
-    out_array = np.vstack([charges, np.array(dipoles).T]).T
+        out_name = "{}_charges_dipoles.dat".format(out_head)
 
-    np.savetxt(
-        out_name,
-        out_array,
-        header="Charges, dipole_x (A e), dipole_y (A e), dipole_z (A e)",
-        fmt="% 7.5e"
-    )
+        # output array of charges, dip_x, dip_y, dip_z
+        out_array = np.vstack([charges, np.array(dipoles).T]).T
 
-    print("Charges and dipoles are written to")
-    print("{}".format(out_name))
+        np.savetxt(
+            out_name,
+            out_array,
+            header="Charges (e), dipole_x (A e), dipole_y (A e), dipole_z (A e)",
+            fmt="% 7.5e"
+        )
+
+        print("Charges and dipoles are written to")
+        print("{}".format(out_name))
+
+    else:
+
+        # Extract charges
+        charges = cd_extractor.get_chelpg_charges(
+            user_args.log_file_name
+        )
+
+        out_head = user_args.log_file_name.split(".")[0]
+
+        out_name = "{}_charges.dat".format(out_head)
+
+        np.savetxt(
+            out_name,
+            charges,
+            header="Charges (e)",
+            fmt="% 7.5e"
+        )
+
+        print("Charges are written to")
+        print("{}".format(out_name))
 
     return
 
@@ -816,6 +839,14 @@ def read_args(arg_list=None):
         help="Gaussian .log file name"
     )
 
+    cd_extract.add_argument(
+        "--mode",
+        type=str,
+        choices={"charges_dipoles", "charges"},
+        default="charges_dipoles",
+        help="Type of decomposition to extract from .log file"
+    )
+
     # Charges and dipoles extraction
 
     geom_conv = subparsers.add_parser(
