@@ -754,6 +754,19 @@ def gen_input(f_name: str, labels: list[str], coords: ArrayLike,
         if element in unique_elements
     }
 
+    # Check all atoms have either ECP or Basis set specified
+    undefined_basis = [
+        element
+        for element in unique_elements
+        if element not in ecp_spec.keys()
+        and element not in bs_spec.keys()
+    ]
+    if any(undefined_basis):
+        msg = "No basis sets/ecp defined for "
+        for udb in undefined_basis:
+            msg += "{} ".format(udb)
+        raise ValueError(msg)
+
     # Create basis set and ecp specification
     basis, pseudo = create_basis(bs_spec, ecp_spec=ecp_spec)
     if len(pseudo):
